import axios from "axios";

export const load = (id: string) =>
  axios.get("/api/" + id).then((response) => {
    if (response.data == "") throw "Invalid Journey Data Received";
    let res = response.data;

    for (let e of res.main) {
      if (e.dateRange) {
        e.dateRange[0] = new Date(e.dateRange[0]);
        e.dateRange[1] = new Date(e.dateRange[1]);
      }
      e.step_title = e.step_title || [];
    }
    return res;
  });

export const save = (id: string, v: string) =>
  axios
    .post("/api/" + id, v)
    .then((response) => {
      console.log("Saved...");
    })
    .catch((error) => {
      console.warn("Error! Could not reach the API.");
    });

export const query_nominatim = (
  q: string,
  f: (v: string) => Boolean = () => true,
) =>
  axios
    .get("/api/place/" + q)
    .then((res) => res.data)
    .then((res) => res.filter(f));

export const query_flight = (q: string) =>
  axios.get("/api/flight/" + q).then((res) => res.data);

type NominatimResult = {
  type: string;
  category: string;
  display_name: string; // DEBUG ONLY
};

export const is_restauration_type = (e: NominatimResult) =>
  ["restaurant", "cafe", "pub", "bar", "fast_food", "food_court"].indexOf(
    e.type,
  ) != -1;

export const is_attraction_type = (e: NominatimResult): boolean =>
  [
    "tourism",
    "leisure",
    "place",
    "amenity",
    "highway",
    "historic",
    "natural",
    "waterway",
  ].indexOf(e.category) != -1 ||
  [
    "place_of_worship",
    "national_park",
    "nature_reserve",
    "protected_area",
  ].indexOf(e.type) != -1;

export const icon_type = (item: NominatimResult): string => {
  let t = item.type;
  let c = item.category;
  const arr = ["restaurant", "cafe", "pub", "bar", "fast_food", "food_court"];
  if (arr.indexOf(t) != -1) {
    return "utensils";
  } else if (t == "hotel" || t == "hostel" || t == "guest_house") {
    return "bed";
  } else if (t == "museum" || c == "historic" || t == "place_of_worship") {
    return "landmark";
  } else if (t == "peak" || t == "viewpoint") {
    return "mountain";
  } else if (t == "parking") {
    return "parking";
  } else if (
    t == "water" ||
    t == "river" ||
    t == "lake" ||
    t == "torrent" ||
    t == "aquarium"
  ) {
    return "water";
  } else if (t == "community_centre" || t == "locality") {
    return "building";
  } else if (t == "attraction") {
    return "landmark";
  } else if (t == "information" || t == "university") {
    return "landmark";
  } else if (t == "bridge") {
    return "archway";
  } else if (
    t == "woodland" ||
    t == "shieling" ||
    t == "national_park" ||
    t == "zoo" ||
    t == "park" ||
    t == "garden" ||
    0
  ) {
    return "tree";
  } else if (t == "water_park" || t == "theme_park") {
    return "dice-five";
  } else if (
    t == "?" ||
    t == "neighbourhood" ||
    t == "quarter" ||
    c == "highway"
  ) {
    return "";
  } else {
    console.log(item.display_name, item.category, item.type);
    return "question";
  }
};
